=begin
Copyright 2010 Vincent Carmona
vinc4mai+taglib@gmail.com

This file is part of ruby-taglib2.

    ruby-taglib2 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    ruby-taglib2 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with ruby-taglib2; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
=end

class TLFileTest < Test::Unit::TestCase
	@@tmp=TaglibTestsUtil.tmp
	@@read=TaglibTestsUtil.read
	@@empty=TaglibTestsUtil.empty
	@@write=TaglibTestsUtil.write
	@@exceptions=TaglibTestsUtil.exceptions

	def TLFileTest.suite
		suite=super
		def suite.setup
			TaglibTestsUtil.setup
		end
		def suite.teardown
			TaglibTestsUtil.teardown
		end
		suite
	end

	def test_new
		assert_nothing_raised{TagLib::File.new(@@read)}
	end

	def test_badfile
		assert_raise(TagLib::BadFile){TagLib::File.new(@@empty)}
	end

	def test_badtag
		assert_raise(TagLib::BadTag){
			f=TagLib::File.new(@@exceptions)
			f.title
		}
	end

	def test_badaudio
		assert_raise(TagLib::BadAudioProperties){
			f=TagLib::File.new(@@exceptions)
			f.length
		}
	end

	def read_tag(file, tag)
		assert_equal(tag[:title], file.title)
		assert_equal(tag[:artist], file.artist)
		assert_equal(tag[:album], file.album)
		assert_equal(tag[:comment], file.comment)
		assert_equal(tag[:genre], file.genre)
		assert_equal(tag[:year], file.year)
		assert_equal(tag[:track], file.track)
	end

	def test_read
		f=TagLib::File.new(@@read)
		read_tag(f, {:title=>'Title', :artist=>'Artist', :album=>'Album',
			:comment=>'Comment', :genre=>'Genre', :year=>2010, :track=>12})
#		assert_equal(, f.length)
		assert_equal(62, f.bitrate)
		assert_equal(8000, f.samplerate)
		assert_equal(1, f.channels)
	end

	def test_write
		f=TagLib::File.new(@@write)
		f.title="title"
		f.artist="artist"
		f.album="album"
		f.comment="comment"
		f.genre="genre"
		f.year=1020
		f.track=21
		f.save
		read_tag(TagLib::File.new(@@write), {:title=>'title', :artist=>'artist',
			:album=>'album', :comment=>'comment', :genre=>'genre',
			:year=>1020, :track=>21})
	end
end
